@@ -23,10 +23,9 @@
 #define __GVC_ELEMENT_H__
 
 #include <glib.h>
-#include <gtk/gtknotebook.h>
-#include <libgnomeui/gnome-appbar.h>
+#include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
-#include <gst/mixer/mixer.h>
+#include <gst/interfaces/mixer.h>
 
 G_BEGIN_DECLS
 
@@ -40,7 +39,7 @@ G_BEGIN_DECLS
 			    GnomeVolumeControlElementClass))
 #define GNOME_VOLUME_CONTROL_IS_ELEMENT(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_VOLUME_CONTROL_TYPE_ELEMENT))
-#define GNOME_VOLUME_CONTROL_IS_ELEMENT_CLASS(obj) \
+#define GNOME_VOLUME_CONTROL_IS_ELEMENT_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_VOLUME_CONTROL_TYPE_ELEMENT))
 
 typedef struct _GnomeVolumeControlElement {
@@ -51,9 +50,6 @@ typedef struct _GnomeVolumeControlElement {
 
   /* gconf client inherited from our parent */
   GConfClient *client;
-
-  /* status bar */
-  GnomeAppBar *appbar;
 } GnomeVolumeControlElement;
 
 typedef struct _GnomeVolumeControlElementClass {
@@ -61,9 +57,7 @@ typedef struct _GnomeVolumeControlElementClass {
 } GnomeVolumeControlElementClass;
 
 GType		gnome_volume_control_element_get_type	(void);
-GtkWidget *	gnome_volume_control_element_new	(GstElement  *element,
-							 GConfClient *client,
-							 GnomeAppBar *appbar);
+GtkWidget *	gnome_volume_control_element_new	(GConfClient  *client);
 void		gnome_volume_control_element_change	(GnomeVolumeControlElement *el,
 							 GstElement  *element);
 
@@ -76,6 +70,9 @@ typedef struct {
   gboolean done;
 } gvc_whitelist;
 
+/* Translator comment: the names below are a whitelist for which volume
+ * controls to show by default. Make sure that those match the translations
+ * of GStreamer-plugins' ALSA/OSS plugins. */
 #define whitelist_init_list { \
     { "cd", FALSE }, \
     { "line", FALSE }, \
@@ -85,6 +82,9 @@ typedef struct {
     { "speaker", FALSE }, \
     { "volume", FALSE }, \
     { "master", FALSE }, \
+    { "digital output", FALSE }, \
+    { "recording", FALSE }, \
+    { "front", FALSE }, \
     { NULL, FALSE } \
   }
 
